@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: pkginfo.sh,v 1.5 2001/12/19 14:37:16 wagner Exp $
+# $Id: pkginfo.sh,v 1.6 2003/01/31 19:34:18 wagner Exp $
 
 if [ -n "$ROOT" -a -d "$ROOT" ] ; then
   sysinfo="$ROOT/scripts/sysinfo.sh"
@@ -50,6 +50,17 @@ pkgpath() {
   fi
 }
 
+listpkgs() {
+  if [ -n "$1" ] ; then
+    while [ -n "$1" ] ; do
+      egrep "$1" "$PKGSDB"
+      shift
+    done | sed -e "s;^;${ROOT}/;"
+  else
+    cat "$PKGSDB" | sed -e "s;^;${ROOT}/;"
+  fi
+}
+
 syscall_wrappers_exist() {
   T1="${ROOT}/m3-libs/m3core/src/runtime/${TARGET}/RTHeapDepC.c"
   T1="${ROOT}/m3-libs/m3gc-enhanced/src/runtime/${TARGET}/RTHeapDepC.c"
